@@ -69,6 +69,7 @@ class Przelewy24Provider(BasicProvider):
         return requests.post(self.endpoint, data=post)
 
     def process_data(self, payment, request):
+        logging.info("Process Przelewy24's notification: body={request.body}")
         try:
             data = json.loads(request.body.decode("utf-8"))
             form = ProcessForm(payment=payment, config=self._config, data=data)
@@ -84,6 +85,6 @@ class Przelewy24Provider(BasicProvider):
                 logger.error("\n".join(*form.errors.values()))
                 return HttpResponseBadRequest("Failed - incorrect data")
         except Exception as e:
-            logger.error(str(e))
+            logger.error(str(e), request.body.decode("utf-8"))
             return HttpResponseBadRequest("Failed")
         return HttpResponse("OK")
